@@ -354,23 +354,55 @@ class NamedCurve(ObjectIdentifier):
         '1.2.840.10045.3.1.5': 'prime239v2',
         '1.2.840.10045.3.1.6': 'prime239v3',
         # https://tools.ietf.org/html/rfc5480#page-5
-        # http://www.secg.org/sec2-v2.pdf
+        # http://www.secg.org/SEC2-Ver-1.0.pdf
+        '1.2.840.10045.3.1.1': 'secp192r1',
+        '1.2.840.10045.3.1.7': 'secp256r1',
         '1.3.132.0.1': 'sect163k1',
+        '1.3.132.0.2': 'sect163r1',
+        '1.3.132.0.3': 'sect239k1',
+        '1.3.132.0.4': 'sect113r1',
+        '1.3.132.0.5': 'sect113r2',
+        '1.3.132.0.6': 'secp112r1',
+        '1.3.132.0.7': 'secp112r2',
+        '1.3.132.0.8': 'secp160r1',
+        '1.3.132.0.9': 'secp160k1',
         '1.3.132.0.10': 'secp256k1',
         '1.3.132.0.15': 'sect163r2',
-        '1.2.840.10045.3.1.1': 'secp192r1',
-        '1.3.132.0.33': 'secp224r1',
-        '1.3.132.0.26': 'sect233k1',
-        '1.2.840.10045.3.1.7': 'secp256r1',
-        '1.3.132.0.27': 'sect233r1',
         '1.3.132.0.16': 'sect283k1',
         '1.3.132.0.17': 'sect283r1',
+        '1.3.132.0.22': 'sect131r1',
+        '1.3.132.0.23': 'sect131r2',
+        '1.3.132.0.24': 'sect193r1',
+        '1.3.132.0.25': 'sect193r2',
+        '1.3.132.0.26': 'sect233k1',
+        '1.3.132.0.27': 'sect233r1',
+        '1.3.132.0.28': 'secp128r1',
+        '1.3.132.0.29': 'secp128r2',
+        '1.3.132.0.30': 'secp160r2',
+        '1.3.132.0.31': 'secp192k1',
+        '1.3.132.0.32': 'secp224k1',
+        '1.3.132.0.33': 'secp224r1',
         '1.3.132.0.34': 'secp384r1',
+        '1.3.132.0.35': 'secp521r1',
         '1.3.132.0.36': 'sect409k1',
         '1.3.132.0.37': 'sect409r1',
-        '1.3.132.0.35': 'secp521r1',
         '1.3.132.0.38': 'sect571k1',
         '1.3.132.0.39': 'sect571r1',
+        # https://tools.ietf.org/html/rfc5639#section-4.1
+        '1.3.36.3.3.2.8.1.1.1': 'brainpoolp160r1',
+        '1.3.36.3.3.2.8.1.1.2': 'brainpoolp160t1',
+        '1.3.36.3.3.2.8.1.1.3': 'brainpoolp192r1',
+        '1.3.36.3.3.2.8.1.1.4': 'brainpoolp192t1',
+        '1.3.36.3.3.2.8.1.1.5': 'brainpoolp224r1',
+        '1.3.36.3.3.2.8.1.1.6': 'brainpoolp224t1',
+        '1.3.36.3.3.2.8.1.1.7': 'brainpoolp256r1',
+        '1.3.36.3.3.2.8.1.1.8': 'brainpoolp256t1',
+        '1.3.36.3.3.2.8.1.1.9': 'brainpoolp320r1',
+        '1.3.36.3.3.2.8.1.1.10': 'brainpoolp320t1',
+        '1.3.36.3.3.2.8.1.1.11': 'brainpoolp384r1',
+        '1.3.36.3.3.2.8.1.1.12': 'brainpoolp384t1',
+        '1.3.36.3.3.2.8.1.1.13': 'brainpoolp512r1',
+        '1.3.36.3.3.2.8.1.1.14': 'brainpoolp512t1',
     }
 
     _key_sizes = {
@@ -403,22 +435,57 @@ class NamedCurve(ObjectIdentifier):
         '1.2.840.10045.3.1.6': 30,
         # Order values used to compute these sourced from
         # http://www.secg.org/SEC2-Ver-1.0.pdf
+        # ceil(n.bit_length() / 8)
+        '1.2.840.10045.3.1.1': 24,
+        '1.2.840.10045.3.1.7': 32,
         '1.3.132.0.1': 21,
+        '1.3.132.0.2': 21,
+        '1.3.132.0.3': 30,
+        '1.3.132.0.4': 15,
+        '1.3.132.0.5': 15,
+        '1.3.132.0.6': 14,
+        '1.3.132.0.7': 14,
+        '1.3.132.0.8': 21,
+        '1.3.132.0.9': 21,
         '1.3.132.0.10': 32,
         '1.3.132.0.15': 21,
-        '1.2.840.10045.3.1.1': 24,
-        '1.3.132.0.33': 28,
-        '1.3.132.0.26': 29,
-        '1.2.840.10045.3.1.7': 32,
-        '1.3.132.0.27': 29,
         '1.3.132.0.16': 36,
         '1.3.132.0.17': 36,
+        '1.3.132.0.22': 17,
+        '1.3.132.0.23': 17,
+        '1.3.132.0.24': 25,
+        '1.3.132.0.25': 25,
+        '1.3.132.0.26': 29,
+        '1.3.132.0.27': 30,
+        '1.3.132.0.28': 16,
+        '1.3.132.0.29': 16,
+        '1.3.132.0.30': 21,
+        '1.3.132.0.31': 24,
+        '1.3.132.0.32': 29,
+        '1.3.132.0.33': 28,
         '1.3.132.0.34': 48,
-        '1.3.132.0.36': 51,
-        '1.3.132.0.37': 51,
         '1.3.132.0.35': 66,
+        '1.3.132.0.36': 51,
+        '1.3.132.0.37': 52,
         '1.3.132.0.38': 72,
         '1.3.132.0.39': 72,
+        # Order values used to compute these sourced from
+        # https://tools.ietf.org/html/rfc5639#section-3
+        # ceil(q.bit_length() / 8)
+        '1.3.36.3.3.2.8.1.1.1': 20,
+        '1.3.36.3.3.2.8.1.1.2': 20,
+        '1.3.36.3.3.2.8.1.1.3': 24,
+        '1.3.36.3.3.2.8.1.1.4': 24,
+        '1.3.36.3.3.2.8.1.1.5': 28,
+        '1.3.36.3.3.2.8.1.1.6': 28,
+        '1.3.36.3.3.2.8.1.1.7': 32,
+        '1.3.36.3.3.2.8.1.1.8': 32,
+        '1.3.36.3.3.2.8.1.1.9': 40,
+        '1.3.36.3.3.2.8.1.1.10': 40,
+        '1.3.36.3.3.2.8.1.1.11': 48,
+        '1.3.36.3.3.2.8.1.1.12': 48,
+        '1.3.36.3.3.2.8.1.1.13': 64,
+        '1.3.36.3.3.2.8.1.1.14': 64,
     }
 
     @classmethod
